summaryrefslogtreecommitdiffstats
path: root/kmymoney2/views/kbudgetview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/views/kbudgetview.h')
-rw-r--r--kmymoney2/views/kbudgetview.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kmymoney2/views/kbudgetview.h b/kmymoney2/views/kbudgetview.h
index 659736e..afe6112 100644
--- a/kmymoney2/views/kbudgetview.h
+++ b/kmymoney2/views/kbudgetview.h
@@ -44,18 +44,18 @@ class KMyMoneyAccountTreeBudgetItem;
*
* This class represents an item in the budgets list view.
*/
-class KBudgetListItem : public KListViewItem
+class KBudgetListItem : public TDEListViewItem
{
public:
/**
* Constructor to be used to construct a budget entry object.
*
* @param parent pointer to the KListView object this entry should be
* added to.
* @param budget const reference to MyMoneyBudget for which
* the KListView entry is constructed
*/
- KBudgetListItem(KListView *parent, const MyMoneyBudget& budget);
+ KBudgetListItem(TDEListView *parent, const MyMoneyBudget& budget);
~KBudgetListItem();
/**
@@ -182,7 +182,7 @@ private slots:
* @param i the item on which the cursor resides
* @param p position of the pointing device
*/
- void slotOpenContextMenu(KListView* lv, TQListViewItem* i, const TQPoint& p);
+ void slotOpenContextMenu(TDEListView* lv, TQListViewItem* i, const TQPoint& p);
signals:
/**
@@ -44,18 +44,18 @@ class KMyMoneyAccountTreeBudgetItem;
* Constructor to be used to construct a budget entry object.
*
- * @param parent pointer to the KListView object this entry should be
+ * @param parent pointer to the TDEListView object this entry should be
* added to.
* @param budget const reference to MyMoneyBudget for which
@@ -44,18 +44,18 @@ class KMyMoneyAccountTreeBudgetItem;
* added to.
* @param budget const reference to MyMoneyBudget for which
- * the KListView entry is constructed
+ * the TDEListView entry is constructed
*/